==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QTextLength_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qtextformat.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTextLength(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextLength")
    QTextLength *_ptr = reinterpret_cast<QTextLength *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QTextLength()
void __qt_construct_QTextLength_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextLength()")
    Q_UNUSED(__java_arguments)
    QTextLength *__qt_this = new(__qtjambi_ptr) QTextLength();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QTextLength(QTextLength::Type,qreal)
void __qt_construct_QTextLength_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextLength(QTextLength::Type,qreal)")
    jobject type0 = __java_arguments[0].l;
    QTextLength::Type __qt_type0 = qtjambi_cast<QTextLength::Type>(__jni_env, type0);
    jdouble value1 = __java_arguments[1].d;
    Q_UNUSED(value1)
    QTextLength *__qt_this = new(__qtjambi_ptr) QTextLength(QTextLength::Type(__qt_type0), static_cast<qreal>(value1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QTextLength
void __qt_destruct_QTextLength(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextLength")
    reinterpret_cast<QTextLength*>(ptr)->~QTextLength();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextLength::QTextLength()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_initialize_1native__Lio_qt_gui_QTextLength_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextLength::QTextLength()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextLength_0, sizeof(QTextLength), typeid(QTextLength), false, &deleter_QTextLength, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextLength::QTextLength(QTextLength::Type,qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_initialize_1native__Lio_qt_gui_QTextLength_2Lio_qt_gui_QTextLength_00024Type_2D)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0,
 jdouble value1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextLength::QTextLength(QTextLength::Type,qreal)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = type0;
        arguments[1].d = value1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextLength_1, sizeof(QTextLength), typeid(QTextLength), false, &deleter_QTextLength, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextLength::operator==(QTextLength)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_equals_1native_1cref_1QTextLength_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextLength::operator==(QTextLength)const", __qt_this)
        const QTextLength& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QTextLength>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextLength::rawValue()const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_rawValue_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextLength::rawValue()const", __qt_this)
        qreal __qt_return_value = __qt_this->rawValue();
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextLength::type()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_type_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextLength::type()const", __qt_this)
        QTextLength::Type __qt_return_value = __qt_this->type();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextLength::value(qreal)const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_value_1native_1qreal_1constfct__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble maximumLength0)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextLength::value(qreal)const", __qt_this)
        qreal __qt_return_value = __qt_this->value(static_cast<qreal>(maximumLength0));
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << *__qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTextLength(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTextLength>("QTextLength", "io/qt/gui/QTextLength");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextLength, {
        ConstructorInfo(&__qt_construct_QTextLength_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QTextLength_1, "Lio/qt/gui/QTextLength$Type;D")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextLength);
    registerMetaType<QTextLength>("QTextLength");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QTextLength::Type>("QTextLength::Type", "io/qt/gui/QTextLength$Type");
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QTextLength_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qtextformat.h>
#include <QtCore/QVariant>
#include <QtCore/qdatastream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTextLength(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextLength")
    QTextLength *_ptr = reinterpret_cast<QTextLength *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QTextLength()
void __qt_construct_QTextLength(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextLength()")
    Q_UNUSED(__java_arguments)
    QTextLength *__qt_this = new(__qtjambi_ptr) QTextLength();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTextLength::QTextLength()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_initialize_1native__Lio_qt_gui_QTextLength_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextLength::QTextLength()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextLength, sizeof(QTextLength), typeid(QTextLength), false, &deleter_QTextLength, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QTextLength(QTextLength)
void __qt_construct_QTextLength_cref_QTextLength(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextLength(QTextLength)")
    jobject other0 = __java_arguments[0].l;
    const QTextLength& __qt_other0 = qtjambi_cast<const QTextLength& >(__jni_env, other0);
    QTextLength *__qt_this = new(__qtjambi_ptr) QTextLength(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTextLength::QTextLength(QTextLength)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_initialize_1native__Lio_qt_gui_QTextLength_2Lio_qt_gui_QTextLength_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextLength::QTextLength(QTextLength)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextLength_cref_QTextLength, sizeof(QTextLength), typeid(QTextLength), false, &deleter_QTextLength, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QTextLength(QTextLength::Type,qreal)
void __qt_construct_QTextLength_QTextLength_Type_qreal(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextLength(QTextLength::Type,qreal)")
    jobject type0 = __java_arguments[0].l;
    QTextLength::Type __qt_type0 = qtjambi_cast<QTextLength::Type>(__jni_env, type0);
    jdouble value1 = __java_arguments[1].d;
    Q_UNUSED(value1)
    QTextLength *__qt_this = new(__qtjambi_ptr) QTextLength(QTextLength::Type(__qt_type0), static_cast<qreal>(value1));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTextLength::QTextLength(QTextLength::Type,qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_initialize_1native__Lio_qt_gui_QTextLength_2Lio_qt_gui_QTextLength_00024Type_2D)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0,
 jdouble value1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextLength::QTextLength(QTextLength::Type,qreal)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = type0;
        arguments[1].d = value1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextLength_QTextLength_Type_qreal, sizeof(QTextLength), typeid(QTextLength), false, &deleter_QTextLength, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTextLength
void __qt_destruct_QTextLength(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextLength")
    reinterpret_cast<QTextLength*>(ptr)->~QTextLength();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextLength::operator<<(QDataStream&,QTextLength)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_writeTo_1native_1ref_1QDataStream__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextLength::operator<<(QDataStream&,QTextLength)", __qt_this)
        QDataStream& __qt_arg__1 = QtJambiAPI::objectReferenceFromNativeId<QDataStream>(__jni_env, arg__1);
        __qt_arg__1 << (*__qt_this);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextLength::operator==(QTextLength)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_equals_1native_1cref_1QTextLength_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextLength::operator==(QTextLength)const", __qt_this)
        const QTextLength& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QTextLength>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextLength::operator>>(QDataStream&,QTextLength&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_readFrom_1native_1ref_1QDataStream__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextLength::operator>>(QDataStream&,QTextLength&)", __qt_this)
        QDataStream& __qt_arg__1 = QtJambiAPI::objectReferenceFromNativeId<QDataStream>(__jni_env, arg__1);
        __qt_arg__1 >> (*__qt_this);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextLength::rawValue()const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_rawValue_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextLength::rawValue()const", __qt_this)
        qreal __qt_return_value = __qt_this->rawValue();
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextLength::type()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_type_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextLength::type()const", __qt_this)
        QTextLength::Type __qt_return_value = __qt_this->type();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextLength::value(qreal)const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_value_1native_1qreal_1constfct__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble maximumLength0)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextLength::value(qreal)const", __qt_this)
        qreal __qt_return_value = __qt_this->value(static_cast<qreal>(maximumLength0));
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << *__qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLength_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTextLength *__qt_this = QtJambiAPI::objectFromNativeId<QTextLength>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTextLength(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTextLength>("QTextLength", "io/qt/gui/QTextLength");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextLength, {
        ConstructorInfo(&__qt_construct_QTextLength, nullptr)
       ,ConstructorInfo(&__qt_construct_QTextLength_cref_QTextLength, "Lio/qt/gui/QTextLength;")
       ,ConstructorInfo(&__qt_construct_QTextLength_QTextLength_Type_qreal, "Lio/qt/gui/QTextLength$Type;D")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextLength);
    registerMetaType<QTextLength>("QTextLength");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QTextLength::Type>("QTextLength::Type", "io/qt/gui/QTextLength$Type");
// END: enums and flags
}
